==> haskell-infinite-list-0.1.2-99.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-infinite-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 infinite-list
version:              0.1.2
visibility:           public
id:                   infinite-list-0.1.2-FdB6Xev5mO691BUO3V7cPB
key:                  infinite-list-0.1.2-FdB6Xev5mO691BUO3V7cPB
license:              BSD-3-Clause
maintainer:           andrew.lelechenko@gmail.com
author:               Bodigrim
homepage:             https://github.com/Bodigrim/infinite-list
synopsis:             Infinite lists
description:
    Modern lightweight library for infinite lists with fusion:

    * API similar to "Data.List".
    * No dependencies other than `base`.
    * Top performance, driven by fusion.
    * Avoid dangerous instances like `Foldable`.
    * Use `NonEmpty` where applicable.
    * Use `Word` for indices.
    * Be lazy, but not too lazy.

    @
    {\-# LANGUAGE PostfixOperators #-\}
    import Data.List.Infinite (Infinite(..), (...), (....))
    import qualified Data.List.Infinite as Inf
    @

category:             Data
abi:                  0615a7c8c9b832eea2dfad12b4d65a86
exposed:              True
exposed-modules:      Data.List.Infinite
hidden-modules:
    Data.List.Infinite.Internal Data.List.Infinite.Set
    Data.List.Infinite.Zip

import-dirs:          /usr/lib/ghc-9.6.6/site-local/infinite-list-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/infinite-list-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/infinite-list-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infinite-list
hs-libraries:         HSinfinite-list-0.1.2-FdB6Xev5mO691BUO3V7cPB
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-infinite-list/html/infinite-list.haddock

haddock-html:         /usr/share/doc/haskell-infinite-list/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-infinite-list-0.1.2-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-infinite-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 infinite-list
version:              0.1.2
visibility:           public
id:                   infinite-list-0.1.2-6m4r1y4qavwI3oXcPAiryE
key:                  infinite-list-0.1.2-6m4r1y4qavwI3oXcPAiryE
license:              BSD-3-Clause
maintainer:           andrew.lelechenko@gmail.com
author:               Bodigrim
homepage:             https://github.com/Bodigrim/infinite-list
synopsis:             Infinite lists
description:
    Modern lightweight library for infinite lists with fusion:

    * API similar to "Data.List".
    * No dependencies other than `base`.
    * Top performance, driven by fusion.
    * Avoid dangerous instances like `Foldable`.
    * Use `NonEmpty` where applicable.
    * Use `Word` for indices.
    * Be lazy, but not too lazy.

    @
    {\-# LANGUAGE PostfixOperators #-\}
    import Data.List.Infinite (Infinite(..), (...), (....))
    import qualified Data.List.Infinite as Inf
    @

category:             Data
abi:                  d1f015cc27ba94ad5a416935412f9579
exposed:              True
exposed-modules:      Data.List.Infinite
hidden-modules:
    Data.List.Infinite.Internal Data.List.Infinite.Set
    Data.List.Infinite.Zip

import-dirs:          /usr/lib/ghc-9.6.6/site-local/infinite-list-0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/infinite-list-0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/infinite-list-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-infinite-list
hs-libraries:         HSinfinite-list-0.1.2-6m4r1y4qavwI3oXcPAiryE
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-infinite-list/html/infinite-list.haddock

haddock-html:         /usr/share/doc/haskell-infinite-list/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
